@@ -6,24 +6,22 @@
 // option. This file may not be copied, modified, or distributed
 // except according to those terms.
 
-#![cfg_attr(all(not(doctest), doc), feature(doc_cfg))]
+#![cfg_attr(docsrs, feature(doc_cfg))]
 #![allow(clippy::missing_safety_doc)]
-#![allow(clippy::non_send_fields_in_send_ty)]
+#![allow(clippy::manual_c_str_literals)]
 
-pub use ffi;
 pub use gst_gl;
+pub use gstreamer_gl_egl_sys as ffi;
 
 macro_rules! assert_initialized_main_thread {
     () => {
-        if unsafe { gst::ffi::gst_is_initialized() } != glib::ffi::GTRUE {
-            panic!("GStreamer has not been initialized. Call `gst::init` first.");
+        if !gst::INITIALIZED.load(std::sync::atomic::Ordering::SeqCst) {
+            gst::assert_initialized();
         }
     };
 }
 
-#[allow(clippy::use_self)]
 mod auto;
 pub use auto::*;
 
 mod gl_display_egl;
-pub use gl_display_egl::*;
